summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorDaniel P. Berrangé <berrange@redhat.com>2020-06-16 09:39:12 +0100
committerDaniel P. Berrangé <berrange@redhat.com>2020-06-26 15:36:40 +0100
commitd3475e71bcb397f721eb2a5906f9b015b516eab2 (patch)
tree6eef307d88006ea45d4e045b64c37f65be61860c /scripts
parentd66181c84e8fc8471476ce607f7ad321392350c3 (diff)
downloadlibvirt-d3475e71bcb397f721eb2a5906f9b015b516eab2.tar.gz
scripts: remove use of the term 'whitelist' from build helpers
The term "permitted list" is a better choice for the filtering logic applied. Reviewed-by: Peter Krempa <pkrempa@redhat.com> Signed-off-by: Daniel P. Berrangé <berrange@redhat.com>
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/check-aclrules.py8
-rwxr-xr-xscripts/check-file-access.py16
-rw-r--r--scripts/mock-noinline.py1
3 files changed, 12 insertions, 13 deletions
diff --git a/scripts/mock-noinline.py b/scripts/mock-noinline.py
index 4fc60c0be3..a8b7680c11 100644
--- a/scripts/mock-noinline.py
+++ b/scripts/mock-noinline.py
@@ -23,7 +23,6 @@ noninlined = {}
mocked = {}
# Functions in public header don't get the noinline annotation
-# so whitelist them here
noninlined["virEventAddTimeout"] = True
# This one confuses the script as its defined in the mock file
# but is actually just a local helper
diff --git a/scripts/check-aclrules.py b/scripts/check-aclrules.py
index a1fa473174..2335e8cfdd 100755
--- a/scripts/check-aclrules.py
+++ b/scripts/check-aclrules.py
@@ -35,7 +35,7 @@
import re
import sys
-whitelist = {
+permitted = {
"connectClose": True,
"connectIsEncrypted": True,
"connectIsSecure": True,
@@ -58,7 +58,7 @@ whitelist = {
# XXX this vzDomainMigrateConfirm3Params looks
# bogus - determine why it doesn't have a valid
# ACL check.
-implwhitelist = {
+implpermitted = {
"vzDomainMigrateConfirm3Params": True,
}
@@ -230,8 +230,8 @@ def process_file(filename):
api not in ["no", "name"] and
table != "virStateDriver"):
if (impl not in acls and
- api not in whitelist and
- impl not in implwhitelist):
+ api not in permitted and
+ impl not in implpermitted):
print(("%s:%d Missing ACL check in " +
"function '%s' for '%s'") %
(filename, lineno, impl, api),
diff --git a/scripts/check-file-access.py b/scripts/check-file-access.py
index dd39de2d79..aa120cafac 100755
--- a/scripts/check-file-access.py
+++ b/scripts/check-file-access.py
@@ -25,16 +25,16 @@ import re
import sys
if len(sys.argv) != 3:
- print("syntax: %s ACCESS-FILE ACCESS-WHITELIST")
+ print("syntax: %s ACCESS-FILE PERMITTED-ACCESS-FILE")
sys.exit(1)
access_file = sys.argv[1]
-whitelist_file = sys.argv[2]
+permitted_file = sys.argv[2]
known_actions = ["open", "fopen", "access", "stat", "lstat", "connect"]
files = []
-whitelist = []
+permitted = []
with open(access_file, "r") as fh:
for line in fh:
@@ -52,7 +52,7 @@ with open(access_file, "r") as fh:
else:
raise Exception("Malformed line %s" % line)
-with open(whitelist_file, "r") as fh:
+with open(permitted_file, "r") as fh:
for line in fh:
line = line.rstrip("\n")
@@ -70,7 +70,7 @@ with open(whitelist_file, "r") as fh:
"progname": m.group(4),
"testname": m.group(6),
}
- whitelist.append(rec)
+ permitted.append(rec)
else:
m = re.search(r'''^(\S*)(:\s*(\S*)(\s*:\s*(.*))?)?$''', line)
if m is not None:
@@ -81,18 +81,18 @@ with open(whitelist_file, "r") as fh:
"progname": m.group(3),
"testname": m.group(5),
}
- whitelist.append(rec)
+ permitted.append(rec)
else:
raise Exception("Malformed line %s" % line)
# Now we should check if %traces is included in $whitelist. For
# now checking just keys is sufficient
err = False
for file in files:
match = False
- for rule in whitelist:
+ for rule in permitted:
if not re.match("^" + rule["path"] + "$", file["path"]):
continue
@@ -81,18 +81,18 @@ with open(whitelist_file, "r") as fh:
else:
raise Exception("Malformed line %s" % line)
-# Now we should check if %traces is included in $whitelist. For
+# Now we should check if %traces is included in $permitted. For
# now checking just keys is sufficient
err = False